﻿using System.Collections.Generic;

namespace NeuroExplorer.NexFile
{
    /// <summary>
    /// Marker variable: a set of timestamps with each timestamp having a number of associated string values.
    /// </summary>
    public class Marker : Event
    {
        /// <summary>
        /// Names of the marker fields.
        /// </summary>
        public List<string> MarkerNames { get; set; }

        /// <summary>
        /// Marker strings. MarkerStrings[0] contains all string values for the first marker field, etc.
        /// </summary>
        public List<List<string>> MarkerStrings { get; set; }

        /// <summary>
        /// Marker values as unsigned integers
        /// NeuroExplorer saves marker values as integers if all marker values are numbers. 
        /// MarkerValues[0] contains all int values for the first marker field, etc.
        /// </summary>
        public List<List<uint>> MarkerValues { get; set; }

        public int MaxMarkerLength { get; set; }

        public Marker() : base()
        {
            MarkerNames = new List<string>();
            MarkerStrings = new List<List<string>>();
            MarkerValues = new List<List<uint>>();
            MaxMarkerLength = 0;
        }
    }
}
