﻿using System.Collections.Generic;

namespace NeuroExplorer.NexFile
{
    public class Waveform : Event
    {
        /// <summary>
        /// Channel number.
        /// </summary>
        public int WireNumber { get; set; }

        /// <summary>
        /// Unit (cluster) number.
        /// </summary>
        public int UnitNumber { get; set; }

        /// <summary>
        /// Array of waveform values in milliVolts. Values[0] contains values of the first waveform, etc.
        /// </summary>
        public List<List<float>> Values { get; set; }

        /// <summary>
        /// Frequency for waveform values in Hertz. The time distance between two consecutive values in one waveform is 1/SamplingRate. 
        /// </summary>
        public double SamplingRate { get; set; }

        /// <summary>
        /// The number of data points in each waveform.
        /// </summary>
        public int NPointsWave { get; set; }

        public double PrethresholdTimeInSeconds { get; set; }

        public double CalulatedCoeffToScaleFloatsToShorts { get; set; }


        /// <summary>
        /// Initializes a new instance of the <see cref="Waveform"/> class.
        /// </summary>
        public Waveform() : base()
        {
            WireNumber = 0;
            UnitNumber = 0;
            Values = new List<List<float>>();
            SamplingRate = 0;
            NPointsWave = 0;
            PrethresholdTimeInSeconds = 0;
            CalulatedCoeffToScaleFloatsToShorts = 1;
        }

        public override double MaxTimestamp()
        {
            int numWaves = Timestamps.Count;
            if ( numWaves > 0 ) {
                double waveStart = Timestamps[ numWaves - 1 ];
                double step = 1.0 / SamplingRate;
                return waveStart + step * ( NPointsWave - 1 );
            } else {
                return 0;
            }
        }
    }
}
